@@ -35,7 +35,7 @@
 
 ////////////////////////////////////////////////////////////////////////////////
 int CmdAnnotations (
-  const CLI& cli,
+  CLI& cli,
   Rules& rules,
   Database& database,
   Journal& journal)
