@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2024, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -36,13 +36,13 @@
 #include <iostream>
 #include <timew.h>
 
-int renderChart (const std::string&, const CLI&, Rules&, Database&);
+int renderChart (const std::string&, CLI&, Rules&, Database&);
 
 std::map <Datetime, std::string> createHolidayMap (Rules&, Range&);
 
 ////////////////////////////////////////////////////////////////////////////////
 int CmdChartDay (
-  const CLI& cli,
+  CLI& cli,
   Rules& rules,
   Database& database)
 {
@@ -51,7 +51,7 @@ int CmdChartDay (
 
 ////////////////////////////////////////////////////////////////////////////////
 int CmdChartWeek (
-  const CLI& cli,
+  CLI& cli,
   Rules& rules,
   Database& database)
 {
@@ -60,7 +60,7 @@ int CmdChartWeek (
 
 ////////////////////////////////////////////////////////////////////////////////
 int CmdChartMonth (
-  const CLI& cli,
+  CLI& cli,
   Rules& rules,
   Database& database)
 {
@@ -70,7 +70,7 @@ int CmdChartMonth (
 ////////////////////////////////////////////////////////////////////////////////
 int renderChart (
   const std::string& type,
-  const CLI& cli,
+  CLI& cli,
   Rules& rules,
   Database& database)
 {
@@ -175,7 +175,7 @@ std::map <Datetime, std::string> createHolidayMap (Rules& rules, Range& range)
   std::map <Datetime, std::string> mapping;
   auto holidays = rules.all ("holidays.");
 
-  for (auto &entry : holidays)
+  for (auto& entry : holidays)
   {
     auto first_dot = entry.find ('.');
     auto last_dot = entry.rfind ('.');
