@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2018, 2020 - 2024, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -33,12 +33,12 @@
 ////////////////////////////////////////////////////////////////////////////////
 // Іdentify DOM references in cli, provide space-separated results.
 int CmdGet (
-  const CLI& cli,
+  CLI& cli,
   Rules& rules,
   Database& database)
 {
   auto references = cli.getDomReferences ();
-  auto filter = Interval {cli.getRange (), cli.getTags()};
+  auto filter = Interval {cli.getRange (), cli.getTags ()};
 
   std::vector <std::string> results;
 
