@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2018, 2020 - 2024, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -76,7 +76,7 @@ static std::string findExtension (
   return "";
 }
 
-std::string basename (const std::string &script_path)
+std::string basename (const std::string& script_path)
 {
   const auto lastSlash = script_path.find_last_of ('/');
 
@@ -107,7 +107,7 @@ std::string getScriptName (const std::string& script_path)
 
 ////////////////////////////////////////////////////////////////////////////////
 int CmdReport (
-  const CLI& cli,
+  CLI& cli,
   Rules& rules,
   Database& database,
   const Extensions& extensions)
